@@ -4,5 +4,5 @@
   packageStartupMessage("If you plan to use the OSRM public API, read the OSRM API Usage Policy:\nhttps://github.com/Project-OSRM/osrm-backend/wiki/Api-usage-policy")
   # options(osrm.server = "http://0.0.0.0:5000/")
   options(osrm.server = "http://router.project-osrm.org/")
-  # options(osrm.server = "http://api-osrm-routed-production.tilestream.net/")
+  options(osrm.profile = "driving")
 }
